@@ -24,8 +24,6 @@ PanelData *panel_setup (PanelToplevel *toplevel);
 
 GtkWidget *make_popup_panel_menu (PanelWidget *panel);
 
-void panel_register_window_icon (void);
-
 GdkScreen *panel_screen_from_panel_widget  (PanelWidget *panel);
 
 gboolean panel_is_applet_right_stick (GtkWidget *applet);
@@ -50,6 +48,8 @@ gboolean panel_check_drop_forbidden (PanelWidget    *panel,
 
 void panel_delete (PanelToplevel *toplevel);
 
+GtkWidget  *panel_deletion_dialog  (PanelToplevel *toplevel);
+
 G_END_DECLS
 
 #endif
